# About

ccbrowse is an open source web application for browsing data from the CALIPSO and CloudSat satellites.

## About CALIPSO and CloudSat

CALIPSO is a satellite carrying a lidar and CloudSat is a satellite carrying a cloud radar. Both have been co-located in the satellite constellation A-Train.

## How to use

Select year, month and day in the navigation bar. Select the time of day (UTC) on the progress bar below the navigation bar. Green/full blue sections of the bar indicate time periods where data for the selected layer are available. Striped grey/blue sections of the bar indicate time periods where data are not available.

Select a layer using the Layers dialog in the top right corner.

Use the +/- buttons in the top left corner to zoom in and out, or use the mouse wheel or pinch to zoom on a touchscreen.

Click/touch and drag the image to move time and height. Height in km is indicated on the left side. The geographical location is indicated at the bottom. The globe in the top right corner shows the location of the satellite at the time corresponding to the center of the image.

Double-click on the image to open a dialog showing the numerical value, date, height, geographical coordinates and the geographical location. Click/tap on the geographical coordinates to view the location on an external map (OpenStreetMap).

Loading of the image tiles might take up several seconds due to a delay in data reading and interpolation.

## Interpolation

Data is interpolated by averaging all data points overlying a given pixel of the resulting image. When the scale of the image is greater than that of the data, ordinary nearest-neighbor interpolation is performed.

## More Information

For more information, please visit ccbrowse on GitHub. Full source code is available, which means that you can run ccbrowse locally or on your own server.

## License

ccbrowse is distributed under terms of an MIT license.

Copyright © 2012–2023 Peter Kuma

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.